\name{cma.fdr}
\alias{cma.fdr}
\title{FDR for Cancer Mutation Prevalence Analysis}
\description{
  Empirical Bayes estimates of the False Discovery Rate (FDR) and
  Passenger Probabilities in Cancer Mutation Prevalence Analysis
}
\usage{
cma.fdr(gene.sizes,
                    passenger.rates = t(data.frame(.55*rep(1.0e-6,25))),
                    cma.data,
                    coverage,
                    allgenes=FALSE,
                    estimate.p0=FALSE,
                    p0.step=1,
                    p0=1,
                    eliminate.noval=TRUE,
                    filter.threshold=0, 
                    filter.above=0,
                    filter.below=0,
                    filter.mutations=0, #
                    aa=1e-10, 
                    bb=1e-10,
                    priorH0=1-500/13020, 
                    prior.a0=100,
                    prior.a1=5,
                    prior.fold=10,
                    M=100)}
\arguments{
  \item{gene.sizes}{Data frame of gene sizes. See GeneSizes object for
    an example.}
  \item{passenger.rates}{Data frame of passenger mutation rates per
    nucleotide, by type, or "context". Columns denote types and must be
    in the same order as the first 25 columns in cma.data objects. If two
    rows are present, they must have row names "Discovery" and
    "Validation"}
  \item{cma.data}{Data frame with mutation information broken down by
    gene, phase and mutation type. See \code{WoodMutationsBreast} for an example. }
  \item{coverage}{Data frame with coverage information, by gene, phase
    and type. See \cite{WoodCoverageBreast} for an example.}
  \item{allgenes}{If TRUE, genes where no mutations were found are
    considered in the analysis.}
  \item{estimate.p0}{If TRUE, estimates the percent of genes with only
    passenger mutations. Requires \code{allgenes=TRUE} }
  \item{p0.step}{Size of bins of histograms in the distribution of
    scores, to use in estimating p0 if estimate.p0 = TRUE. All scores
    are in the log 10 scale.}
  \item{p0}{Proportion of genes with only
    passenger mutations. Only used if \code{estimate.p0=FALSE}}
  \item{eliminate.noval}{If TRUE, the genes which are not validated are
    eliminated from the analysis. Validated genes are those where at
    least one mutation was found in both the discovery and validation screens.}
  \item{filter.threshold}{This and the following three input control
    filtering of genes, allowing to exclude genes from analysis, by size
    and number of mutations. Different criteria can be set above and
    below this threshold. The threshold is a gene size in base pairs.}
  \item{filter.above}{Minimum number of mutations per
    Mb, applied to genes of size greater than \code{threshold.size}.}
  \item{filter.below}{Minimum number of mutations per
    Mb, applied to genes of size lower than \code{threshold.size}.}
  \item{filter.mutations}{Only consider genes
    whose total number of mutations is greater than \code{filter.mutations}.}   \item{aa}{Hyperparameter of beta prior used in compute.binomial.posterior.}
  \item{bb}{Hyperparameter of beta prior used in compute.binomial.posterior.}
  \item{priorH0}{Prior probability of the null hypothesis, used to
    convert the BF in compute.poisson.BF to a posterior probability}
  \item{prior.a0}{Shape hyperparameter of gamma prior on passenger rates used in compute.poisson.BF}
  \item{prior.a1}{Shape hyperparameter of gamma prior on non-passenger rates used in compute.poisson.BF}
  \item{prior.fold}{Hyperparameter of gamma prior  on non-passenger
    rates used compute.poisson.BF. The mean of the gamma is set so that
    the ratio of the mean to the passenger rate is the specified
    \code{prior.fold} in each type.}
  \item{M}{The number of null
    datasets generated  to get the false discovery rates.}
}
\value{
  A list of data frames. Each gives a gene gene-by-gene significance for
  one of the score requested. The columns in
  each data frame are:
  \item{CaMP}{The CaMP score.}
  \item{score}{The score requested (e.g. the LRT).}
  \item{F}{Number of genes experimentally observed to give a larger
    score than the gene in question.}
  \item{F0}{Number of genes giving a larger
    score than the gene in question in datasets simulated from passenger
    mutation rates.}
  \item{Fdr}{The Empirical Bayes False Discovery Rate, as defined in
    Efron and Tibshirani 2002.}
  \item{fdr}{The Empirical Bayes Local False Discovery Rate, as defined in
    Efron and Tibshirani 2002.}
  \item{p0}{Scalar, Proportion of genes with only
    passenger mutations. Estimated or passed on from input (depending on whether estimate.p0 is TRUE} 
}
\references{
Efron B; Tibshirani R.  Empirical {B}ayes methods and false discovery
rates for microarrays. Genetic Epidemiology, 23(1):70--86, 2002.

Parmigiani G, Lin J, Boca S, Sjoeblom T, Kinzler WK,
  Velculescu VE, Vogelstein B. Statistical methods for the analysis of
  cancer genome sequencing data, 2007. 
  \url{http://www.bepress.com/jhubiostat/paper126/}}
\author{Giovanni Parmigiani, Simina Boca}
\seealso{Wood}
\examples{
data(Wood)
cma.fdr.out <- cma.fdr(gene.sizes = GeneSizes,
                       cma.data = WoodMutationsBreast,
                       coverage = WoodCoverageBreast,
                       M = 2,
                       estimate.p0 = TRUE)
names(cma.fdr.out)
}
\keyword{htest}
