\name{cma.simulator}
\alias{cma.simulator}
\title{Generate Cancer Mutation Prevalence Data.}
\description{
  Generates a sample from sequencing
  data in a two stage, screening/validation design.
}
\usage{
cma.simulator(gene.sizes,
           passenger.rates = t(data.frame(0.55*rep(1.0e-6,25))),
           coverage,
           multinomial=FALSE, 
           simulation.type="rates", # also "prevalence"
           eliminate.noval=TRUE,
           filter.mutations=0, 
           random.passenger.rates=FALSE, 
           lognormal.sigma=.58, 
           null.genome=TRUE,
           ncangenes=NULL,
           random.ncangenes=FALSE,
           driver.rates=NULL, 
           driver.prevalences=NULL)
}
\arguments{
  \item{gene.sizes}{Data frame of gene sizes. See GeneSizes object for
    an example.}
  \item{passenger.rates}{Data frame of passenger mutation rates per
    nucleotide, by type, or "context". Columns denote types and must be
    in the same order as the first 25 columns in cma.data objects. If two
    rows are present, they must have row names "Discovery" and
    "Validation"}
  \item{coverage}{Data frame with coverage information, by gene, phase
    and type. See \cite{WoodCoverageBreast} for an example.}
  \item{multinomial}{If TRUE data are simulated from a product multinomal model
    rather than a product binomial model. Very slow.}
  \item{simulation.type}{If "rates", non-passenger mutations are
    generated by specifying gene-specific mutation rates per Mb. If
    "prevalence", non-passenger mutations are generated by specifying
    gene-specific percentages of tumors in which the
    genes are mutated.}
  \item{eliminate.noval}{If TRUE, the genes which are not validated are
    eliminated from the analysis. Validated genes are those where at
    least one mutation was found in both the discovery and validation screens.}
  \item{filter.mutations}{Minimum number of mutations required for a
    gene to be included in the output object. Default is 0. }
  \item{random.passenger.rates}{If TRUE, passenger mutation rates are
    allowed to vary according to a lognormal distribution with sigma
    parameter specified in the \code{lognormal.sigma}}
  \item{lognormal.sigma}{See above.}
  \item{null.genome}{If TRUE, the entire genome is assumed to
    consist of null genes, mutated at passenger rates. If false, some
    genes have mutations above the passenger rates, i.e. are "spiked-in."}
  \item{ncangenes}{The number of spiked-in genes.}
  \item{random.ncangenes}{If true, the number of spiked-in
    genes is random, sampled from Binomial(nG, ncangenes/nG), where
    nG is the total number of genes.}
  \item{driver.rates}{The mutation rates per Mb at which the
    spiked-in genes are mutated, arranged as a data frame with as many rows as
    there are different patterns of deviation from the null, and as many
    columns as mutation types. For each of the spike-in genes, mutation
    are generated by drawing a rate pattern (a row) from
    \code{driver.rates}, and then generating binomial data with those
    rates. Rates lower than passenger rates are reset by default to the
    passenger rates.} 
  \item{driver.prevalences}{The expected percentage of tumors in which the
    spiked-in genes are mutated. For example, to spike-in genes so
    that about 2/3 of the spike-ins are mutated in 4\% of tumors, while 1/3 are mutated in
    6\% of tumors, set \code{driver.prevalences=c(.04,.04,.06)}. 
    The expected percentages for each of the spike-ins are drawn
    from the \code{driver.prevalences} vector. The actual number of
    mutated tumors is then draw from a separate binomial for each gene. }
}
\details{
  Data are generated from a product binomial model described in
  Parmigiani et al. 
}
\value{
  \code{cma.data} object, having same format as
  WoodMutationsBreast and WoodMutationsColon in the
  \code{\link{Wood}} dataset.
  If null.genome = FALSE, an additional column, "TrueDriver", is added,
  specifying which genes have been "spiked-in."
}

\references{
  Parmigiani G, Lin J, Boca S, Sjoeblom T, Kinzler WK,
  Velculescu VE, Vogelstein B. Statistical methods for the analysis of
  cancer genome sequencing data. 
  \url{http://www.bepress.com/jhubiostat/paper126/}
}
\author{Giovanni Parmigiani, Simina Boca}

\seealso{}
\examples{
\dontrun{
data(Wood)
cma.simulator.null <- cma.simulator(gene.sizes = CCDSsizes06,
                        coverage = Sjoeblom06CoverageBreast)
cma.simulator.spike <- cma.simulator(gene.sizes = CCDSsizes06,
                                coverage = Sjoeblom06CoverageColon,
                                null.genome = FALSE,
                                ncangenes = 10,
                                driver.rates = t(data.frame(rep(1.0e-3,7))))
}
}
\keyword{datagen}

